
/*---------------------------------------------------------------------------
 * Copyright (C) 1999,2000 Dallas Semiconductor Corporation, All Rights Reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY,  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL DALLAS SEMICONDUCTOR BE LIABLE FOR ANY CLAIM, DAMAGES
 * OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 * Except as contained in this notice, the name of Dallas Semiconductor
 * shall not be used except as stated in the Dallas Semiconductor
 * Branding Policy.
 *---------------------------------------------------------------------------
 */

package com.dalsemi.onewire.adapter;

// imports
import java.util.Enumeration;
import com.dalsemi.onewire.container.OneWireContainer;
import com.dalsemi.onewire.adapter.*;
import com.dalsemi.onewire.utils.*;
import com.dalsemi.onewire.OneWireException;
import java.util.Vector;
import java.util.Hashtable;


/**
 * Wrapper for iButtonAPI before conversion to OneWireAPI
 *
 * @version    0.00, 21 August 2000
 * @author     DS
 */
public class TINIAdapter
   extends DSPortAdapter
{

   //--------
   //-------- Variables
   //--------
   protected com.ibutton.adapter.DSPortAdapter adapter;

   /**
    * Constructor TINIAdapter
    *
    *
    */
   public TINIAdapter ()
   {
      adapter = new com.ibutton.adapter.TINIExternalAdapter();
   }

   //--------
   //-------- Methods
   //--------

   /**
    * Retrieve the name of the port adapter as a string.  The 'Adapter'
    * is a device that connects to a 'port' that allows one to
    * communicate with an iButton or other 1-Wire device.  As example
    * of this is 'DS9097U'.
    *
    * @return  <code>String</code> representation of the port adapter.
    */
   public String getAdapterName ()
   {
      return adapter.getAdapterName();
   }

   /**
    * Retrieve a description of the port required by this port adapter.
    * An example of a 'Port' would 'serial communication port'.
    *
    * @return  <code>String</code> description of the port type required.
    */
   public String getPortTypeDescription ()
   {
      return adapter.getPortTypeDescription();
   }

   /**
    * Retrieve a version string for this class.
    *
    * @return  version string
    */
   public String getClassVersion ()
   {
      return adapter.getClassVersion();
   }

   //--------
   //-------- Port Selection
   //--------

   /**
    * Retrieve a list of the platform appropriate port names for this
    * adapter.  A port must be selected with the method 'selectPort'
    * before any other communication methods can be used.  Using
    * a communcation method before 'selectPort' will result in
    * a <code>OneWireException</code> exception.
    *
    * @return  enumeration of type <code>String</code> that contains the port
    * names
    */
   public Enumeration getPortNames ()
   {
      return adapter.getPortNames();
   }

   /**
    * Specify a platform appropriate port name for this adapter.  Note that
    * even though the port has been selected, it's ownership may be relinquished
    * if it is not currently held in a 'exclusive' block.  This class will then
    * try to re-aquire the port when needed.  If the port cannot be re-aquired
    * ehen the exception <code>PortInUseException</code> will be thrown.
    *
    * @param  portName  name of the target port, retrieved from
    * getPortNames()
    *
    * @return <code>true</code> if the port was aquired, <code>false</code>
    * if the port is not available.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public boolean selectPort (String portName)
      throws OneWireIOException, OneWireException
   {
      try
      {
         return adapter.selectPort(portName);
      }
      catch (com.ibutton.adapter.OneWireIOException e)
      {
         throw new OneWireIOException(e.toString());
      }
      catch (com.ibutton.iButtonException e)
      {
         throw new OneWireException(e.toString());
      }
   }

   /**
    * Free ownership of the selected port if it is currently owned back
    * to the system.  This should only be called if the recently
    * selected port does not have an adapter or at the end of
    * your application's use of the port.
    *
    * @throws OneWireException
    */
   public void freePort ()
      throws OneWireException
   {
      try
      {
         adapter.freePort();
      }
      catch (com.ibutton.iButtonException e)
      {
         throw new OneWireException(e.toString());
      }
   }

   /**
    * Retrieve the name of the selected port as a <code>String</code>.
    *
    * @return  <code>String</code> of selected port
    *
    * @throws OneWireException
    */
   public String getPortName ()
      throws OneWireException
   {
      try
      {
         return adapter.getPortName();
      }
      catch (com.ibutton.iButtonException e)
      {
         throw new OneWireException(e.toString());
      }
   }

   //--------
   //-------- Adapter detection 
   //--------

   /**
    * Detect adapter presence on the selected port.
    *
    * @return  <code>true</code> if the adapter is confirmed to be connected to
    * the selected port, <code>false</code> if the adapter is not connected.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public boolean adapterDetected ()
      throws OneWireIOException, OneWireException
   {
      try
      {
         return adapter.adapterDetected();
      }
      catch (com.ibutton.adapter.OneWireIOException e)
      {
         throw new OneWireIOException(e.toString());
      }
      catch (com.ibutton.iButtonException e)
      {
         throw new OneWireException(e.toString());
      }
   }

   /**
    * Retrieve the version of the adapter.
    *
    * @return  <code>String</code> of the adapter version.  It will return
    * "<na>" if the adapter version is not or cannot be known.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public String getAdapterVersion ()
      throws OneWireIOException, OneWireException
   {
      try
      {
         return adapter.getAdapterVersion();
      }
      catch (com.ibutton.adapter.OneWireIOException e)
      {
         throw new OneWireIOException(e.toString());
      }
      catch (com.ibutton.iButtonException e)
      {
         throw new OneWireException(e.toString());
      }
   }

   /**
    * Retrieve the address of the adapter if it has one.
    *
    * @return  <code>String</code> of the adapter address.  It will return "<na>" if
    * the adapter does not have an address.  The address is a string representation of an
    * 1-Wire address.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public String getAdapterAddress ()
      throws OneWireIOException, OneWireException
   {
      try
      {
         return adapter.getAdapterAddress();
      }
      catch (com.ibutton.adapter.OneWireIOException e)
      {
         throw new OneWireIOException(e.toString());
      }
      catch (com.ibutton.iButtonException e)
      {
         throw new OneWireException(e.toString());
      }
   }

   //--------
   //-------- Adapter features 
   //--------

   /* The following interogative methods are provided so that client code
    * can react selectively to underlying states without generating an
    * exception.
    */

   /**
    * Returns whether adapter can physically support overdrive mode.
    *
    * @return  <code>true</code> if this port adapter can do OverDrive,
    * <code>false</code> otherwise.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public boolean canOverdrive ()
      throws OneWireIOException, OneWireException
   {
      try
      {
         return adapter.canOverdrive();
      }
      catch (com.ibutton.adapter.OneWireIOException e)
      {
         throw new OneWireIOException(e.toString());
      }
      catch (com.ibutton.iButtonException e)
      {
         throw new OneWireException(e.toString());
      }
   }

   /**
    * Returns whether the adapter can physically support hyperdrive mode.
    *
    * @return  <code>true</code> if this port adapter can do HyperDrive,
    * <code>false</code> otherwise.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public boolean canHyperdrive ()
      throws OneWireIOException, OneWireException
   {
      try
      {
         return adapter.canHyperdrive();
      }
      catch (com.ibutton.adapter.OneWireIOException e)
      {
         throw new OneWireIOException(e.toString());
      }
      catch (com.ibutton.iButtonException e)
      {
         throw new OneWireException(e.toString());
      }
   }

   /**
    * Returns whether the adapter can physically support flex speed mode.
    *
    * @return  <code>true</code> if this port adapter can do flex speed,
    * <code>false</code> otherwise.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public boolean canFlex ()
      throws OneWireIOException, OneWireException
   {
      try
      {
         return adapter.canFlex();
      }
      catch (com.ibutton.adapter.OneWireIOException e)
      {
         throw new OneWireIOException(e.toString());
      }
      catch (com.ibutton.iButtonException e)
      {
         throw new OneWireException(e.toString());
      }
   }

   /**
    * Returns whether adapter can physically support 12 volt power mode.
    *
    * @return  <code>true</code> if this port adapter can do Program voltage,
    * <code>false</code> otherwise.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public boolean canProgram ()
      throws OneWireIOException, OneWireException
   {
      try
      {
         return adapter.canProgram();
      }
      catch (com.ibutton.adapter.OneWireIOException e)
      {
         throw new OneWireIOException(e.toString());
      }
      catch (com.ibutton.iButtonException e)
      {
         throw new OneWireException(e.toString());
      }
   }

   /**
    * Returns whether the adapter can physically support strong 5 volt power
    * mode.
    *
    * @return  <code>true</code> if this port adapter can do strong 5 volt
    * mode, <code>false</code> otherwise.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public boolean canDeliverPower ()
      throws OneWireIOException, OneWireException
   {
      try
      {
         return adapter.canDeliverPower();
      }
      catch (com.ibutton.adapter.OneWireIOException e)
      {
         throw new OneWireIOException(e.toString());
      }
      catch (com.ibutton.iButtonException e)
      {
         throw new OneWireException(e.toString());
      }
   }

   /**
    * Returns whether the adapter can physically support "smart" strong 5
    * volt power mode.  "smart" power delivery is the ability to deliver
    * power until it is no longer needed.  The current drop it detected
    * and power delivery is stopped.
    *
    * @return  <code>true</code> if this port adapter can do "smart" strong
    * 5 volt mode, <code>false</code> otherwise.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public boolean canDeliverSmartPower ()
      throws OneWireIOException, OneWireException
   {
      try
      {
         return adapter.canDeliverSmartPower();
      }
      catch (com.ibutton.adapter.OneWireIOException e)
      {
         throw new OneWireIOException(e.toString());
      }
      catch (com.ibutton.iButtonException e)
      {
         throw new OneWireException(e.toString());
      }
   }

   /**
    * Returns whether adapter can physically support 0 volt 'break' mode.
    *
    * @return  <code>true</code> if this port adapter can do break,
    * <code>false</code> otherwise.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public boolean canBreak ()
      throws OneWireIOException, OneWireException
   {
      try
      {
         return adapter.canBreak();
      }
      catch (com.ibutton.adapter.OneWireIOException e)
      {
         throw new OneWireIOException(e.toString());
      }
      catch (com.ibutton.iButtonException e)
      {
         throw new OneWireException(e.toString());
      }
   }

   //--------
   //-------- Finding iButtons and 1-Wire devices
   //--------

   /**
    * Returns <code>true</code> if the first iButton or 1-Wire device
    * is found on the 1-Wire Network.
    * If no devices are found, then <code>false</code> will be returned.
    *
    * @return  <code>true</code> if an iButton or 1-Wire device is found.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public boolean findFirstDevice ()
      throws OneWireIOException, OneWireException
   {
      try
      {
         return adapter.findFirstiButton();
      }
      catch (com.ibutton.adapter.OneWireIOException e)
      {
         throw new OneWireIOException(e.toString());
      }
      catch (com.ibutton.iButtonException e)
      {
         throw new OneWireException(e.toString());
      }
   }

   /**
    * Returns <code>true</code> if the next iButton or 1-Wire device
    * is found. The previous 1-Wire device found is used
    * as a starting point in the search.  If no more devices are found
    * then <code>false</code> will be returned.
    *
    * @return  <code>true</code> if an iButton or 1-Wire device is found.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public boolean findNextDevice ()
      throws OneWireIOException, OneWireException
   {
      try
      {
         return adapter.findNextiButton();
      }
      catch (com.ibutton.adapter.OneWireIOException e)
      {
         throw new OneWireIOException(e.toString());
      }
      catch (com.ibutton.iButtonException e)
      {
         throw new OneWireException(e.toString());
      }
   }

   /**
    * Copies the 'current' iButton address being used by the adapter into
    * the array.  This address is the last iButton or 1-Wire device found
    * in a search (findNextDevice()...).
    * This method copies into a user generated array to allow the
    * reuse of the buffer.  When searching many iButtons on the one
    * wire network, this will reduce the memory burn rate.
    *
    * @param  address An array to be filled with the current iButton address.
    */
   public void getAddress (byte[] address)
   {
      adapter.getAddress(address);
   }

   /**
    * Verifies that the iButton or 1-Wire device specified is present on
    * the 1-Wire Network. This does not affect the 'current' device
    * state information used in searches (findNextDevice...).
    *
    * @param  address  device address to verify is present
    *
    * @return  <code>true</code> if device is present else
    *         <code>false</code>.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public boolean isPresent (byte[] address)
      throws OneWireIOException, OneWireException
   {
      try
      {
         return adapter.isPresent(address);
      }
      catch (com.ibutton.adapter.OneWireIOException e)
      {
         throw new OneWireIOException(e.toString());
      }
      catch (com.ibutton.iButtonException e)
      {
         throw new OneWireException(e.toString());
      }
   }

   /**
    * Verifies that the iButton or 1-Wire device specified is present
    * on the 1-Wire Network and in an alarm state. This does not
    * affect the 'current' device state information used in searches
    * (findNextDevice...).
    *
    * @param  address  device address to verify is present and alarming
    *
    * @return  <code>true</code> if device is present and alarming else
    * <code>false</code>.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public boolean isAlarming (byte[] address)
      throws OneWireIOException, OneWireException
   {
      try
      {
         return adapter.isAlarming(address);
      }
      catch (com.ibutton.adapter.OneWireIOException e)
      {
         throw new OneWireIOException(e.toString());
      }
      catch (com.ibutton.iButtonException e)
      {
         throw new OneWireException(e.toString());
      }
   }

   /**
    * Selects the specified iButton or 1-Wire device by broadcasting its
    * address.  This operation is refered to a 'MATCH ROM' operation
    * in the iButton and 1-Wire device data sheets.  This does not
    * affect the 'current' device state information used in searches
    * (findNextDevice...).
    *
    * Warning, this does not verify that the device is currently present
    * on the 1-Wire Network (See isPresent).
    *
    * @param  address    address of iButton or 1-Wire device to select
    *
    * @return  <code>true</code> if device address was sent,<code>false</code>
    * otherwise.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    *
    * @see com.dalsemi.onewire.adapter.DSPortAdapter#isPresent(byte[] address)
    */
   public boolean select (byte[] address)
      throws OneWireIOException, OneWireException
   {
      try
      {
         return adapter.select(address);
      }
      catch (com.ibutton.adapter.OneWireIOException e)
      {
         throw new OneWireIOException(e.toString());
      }
      catch (com.ibutton.iButtonException e)
      {
         throw new OneWireException(e.toString());
      }
   }

   //--------
   //-------- Finding iButton/1-Wire device options 
   //--------

   /**
    * Set the 1-Wire Network search to find only iButtons and 1-Wire
    * devices that are in an 'Alarm' state that signals a need for
    * attention.  Not all iButton types
    * have this feature.  Some that do: DS1994, DS1920, DS2407.
    * This selective searching can be canceled with the
    * 'setSearchAllDevices()' method.
    */
   public void setSearchOnlyAlarmingDevices ()
   {
      adapter.setSearchOnlyAlarmingiButtons();
   }

   /**
    * Set the 1-Wire Network search to not perform a 1-Wire
    * reset before a search.  This feature is chiefly used with
    * the DS2409 1-Wire coupler.
    * The normal reset before each search can be restored with the
    * 'setSearchAllDevices()' method.
    */
   public void setNoResetSearch ()
   {
      adapter.setNoResetSearch();
   }

   /**
    * Set the 1-Wire Network search to find all iButtons and 1-Wire
    * devices whether they are in an 'Alarm' state or not and
    * restores the default setting of providing a 1-Wire reset
    * command before each search. (see setNoResetSearch() method).
    */
   public void setSearchAllDevices ()
   {
      adapter.setSearchAlliButtons();
   }

   //--------
   //-------- 1-Wire Network Semaphore methods  
   //--------

   /**
    * Gets exclusive use of the 1-Wire to communicate with an iButton or
    * 1-Wire Device.
    * This method should be used for critical sections of code where a
    * sequence of commands must not be interrupted by communication of
    * threads with other iButtons, and it is permissible to sustain
    * a delay in the special case that another thread has already been
    * granted exclusive access and this access has not yet been
    * relinquished. <p>
    *
    * It can be called through the OneWireContainer
    * class by the end application if they want to ensure exclusive
    * use.  If it is not called around several methods then it
    * will be called inside each method.
    *
    * @param blocking <code>true</code> if want to block waiting
    *                 for an excluse access to the adapter
    * @return <code>true</code> if blocking was false and a
    *         exclusive session with the adapter was aquired
    *
    * @throws OneWireException
    */
   public boolean beginExclusive (boolean blocking)
      throws OneWireException
   {
      try
      {
         return adapter.beginExclusive(blocking);
      }
      catch (com.ibutton.iButtonException e)
      {
         throw new OneWireException(e.toString());
      }
   }

   /**
    * Relinquishes exclusive control of the 1-Wire Network.
    * This command dynamically marks the end of a critical section and
    * should be used when exclusive control is no longer needed.
    */
   public void endExclusive ()
   {
      adapter.endExclusive();
   }

   //--------
   //-------- Primitive 1-Wire Network data methods 
   //--------

   /**
    * Sends a bit to the 1-Wire Network.
    *
    * @param  bitValue  the bit value to send to the 1-Wire Network.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public void putBit (boolean bitValue)
      throws OneWireIOException, OneWireException
   {
      try
      {
         adapter.putBit(bitValue);
      }
      catch (com.ibutton.adapter.OneWireIOException e)
      {
         throw new OneWireIOException(e.toString());
      }
      catch (com.ibutton.iButtonException e)
      {
         throw new OneWireException(e.toString());
      }
   }

   /**
    * Gets a bit from the 1-Wire Network.
    *
    * @return  the bit value recieved from the the 1-Wire Network.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public boolean getBit ()
      throws OneWireIOException, OneWireException
   {
      try
      {
         return adapter.getBit();
      }
      catch (com.ibutton.adapter.OneWireIOException e)
      {
         throw new OneWireIOException(e.toString());
      }
      catch (com.ibutton.iButtonException e)
      {
         throw new OneWireException(e.toString());
      }
   }

   /**
    * Sends a byte to the 1-Wire Network.
    *
    * @param  byteValue  the byte value to send to the 1-Wire Network.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public void putByte (int byteValue)
      throws OneWireIOException, OneWireException
   {
      try
      {
         adapter.putByte(byteValue);
      }
      catch (com.ibutton.adapter.OneWireIOException e)
      {
         throw new OneWireIOException(e.toString());
      }
      catch (com.ibutton.iButtonException e)
      {
         throw new OneWireException(e.toString());
      }
   }

   /**
    * Gets a byte from the 1-Wire Network.
    *
    * @return  the byte value received from the the 1-Wire Network.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public int getByte ()
      throws OneWireIOException, OneWireException
   {
      try
      {
         return adapter.getByte();
      }
      catch (com.ibutton.adapter.OneWireIOException e)
      {
         throw new OneWireIOException(e.toString());
      }
      catch (com.ibutton.iButtonException e)
      {
         throw new OneWireException(e.toString());
      }
   }

   /**
    * Get a block of data from the 1-Wire Network.
    *
    * @param  len  length of data bytes to receive
    *
    * @return  the data received from the 1-Wire Network.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public byte[] getBlock (int len)
      throws OneWireIOException, OneWireException
   {
      try
      {
         return adapter.getBlock(len);
      }
      catch (com.ibutton.adapter.OneWireIOException e)
      {
         throw new OneWireIOException(e.toString());
      }
      catch (com.ibutton.iButtonException e)
      {
         throw new OneWireException(e.toString());
      }
   }

   /**
    * Get a block of data from the 1-Wire Network and write it into
    * the provided array.
    *
    * @param  arr     array in which to write the received bytes
    * @param  len     length of data bytes to receive
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public void getBlock (byte[] arr, int len)
      throws OneWireIOException, OneWireException
   {
      try
      {
         adapter.getBlock(arr, len);
      }
      catch (com.ibutton.adapter.OneWireIOException e)
      {
         throw new OneWireIOException(e.toString());
      }
      catch (com.ibutton.iButtonException e)
      {
         throw new OneWireException(e.toString());
      }
   }

   /**
    * Get a block of data from the 1-Wire Network and write it into
    * the provided array.
    *
    * @param  arr     array in which to write the received bytes
    * @param  off     offset into the array to start
    * @param  len     length of data bytes to receive
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public void getBlock (byte[] arr, int off, int len)
      throws OneWireIOException, OneWireException
   {
      try
      {
         adapter.getBlock(arr, off, len);
      }
      catch (com.ibutton.adapter.OneWireIOException e)
      {
         throw new OneWireIOException(e.toString());
      }
      catch (com.ibutton.iButtonException e)
      {
         throw new OneWireException(e.toString());
      }
   }

   /**
    * Sends a block of data and returns the data received in the same array.
    * This method is used when sending a block that contains reads and writes.
    * The 'read' portions of the data block need to be pre-loaded with 0xFF's.
    * It starts sending data from the index at offset 'off' for length 'len'.
    *
    * @param  dataBlock  array of data to transfer to and from the 1-Wire Network.
    * @param  off        offset into the array of data to start
    * @param  len        length of data to send / receive starting at 'off'
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public void dataBlock (byte dataBlock [], int off, int len)
      throws OneWireIOException, OneWireException
   {
      try
      {
         adapter.dataBlock(dataBlock, off, len);
      }
      catch (com.ibutton.adapter.OneWireIOException e)
      {
         throw new OneWireIOException(e.toString());
      }
      catch (com.ibutton.iButtonException e)
      {
         throw new OneWireException(e.toString());
      }
   }

   /**
    * Sends a Reset to the 1-Wire Network.
    *
    * @return  the result of the reset. Potential results are:
    * <ul>
    * <li> 0 (RESET_NOPRESENCE) no devices present on the 1-Wire Network.
    * <li> 1 (RESET_PRESENCE) normal presence pulse detected on the 1-Wire
    *        Network indicating there is a device present.
    * <li> 2 (RESET_ALARM) alarming presence pulse detected on the 1-Wire
    *        Network indicating there is a device present and it is in the
    *        alarm condition.  This is only provided by the DS1994/DS2404
    *        devices.
    * <li> 3 (RESET_SHORT) inticates 1-Wire appears shorted.  This can be
    *        transient conditions in a 1-Wire Network.  Not all adapter types
    *        can detect this condition.
    * </ul>
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public int reset ()
      throws OneWireIOException, OneWireException
   {
      try
      {
         return adapter.reset();
      }
      catch (com.ibutton.adapter.OneWireIOException e)
      {
         throw new OneWireIOException(e.toString());
      }
      catch (com.ibutton.iButtonException e)
      {
         throw new OneWireException(e.toString());
      }
   }

   //--------
   //-------- 1-Wire Network power methods 
   //--------

   /**
    * Sets the duration to supply power to the 1-Wire Network.
    * This method takes a time parameter that indicates the program
    * pulse length when the method startPowerDelivery().<p>
    *
    * Note: to avoid getting an exception,
    * use the canDeliverPower() and canDeliverSmartPower()
    * method to check it's availability. <p>
    *
    * @param timeFactor
    * <ul>
    * <li>   0 (DELIVERY_HALF_SECOND) provide power for 1/2 second.
    * <li>   1 (DELIVERY_ONE_SECOND) provide power for 1 second.
    * <li>   2 (DELIVERY_TWO_SECONDS) provide power for 2 seconds.
    * <li>   3 (DELIVERY_FOUR_SECONDS) provide power for 4 seconds.
    * <li>   4 (DELIVERY_SMART_DONE) provide power until the
    *          the device is no longer drawing significant power.
    * <li>   5 (DELIVERY_INFINITE) provide power until the
    *          setPowerNormal() method is called.
    * </ul>
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public void setPowerDuration (int timeFactor)
      throws OneWireIOException, OneWireException
   {
      try
      {
         adapter.setPowerDuration(timeFactor);
      }
      catch (com.ibutton.adapter.OneWireIOException e)
      {
         throw new OneWireIOException(e.toString());
      }
      catch (com.ibutton.iButtonException e)
      {
         throw new OneWireException(e.toString());
      }
   }

   /**
    * Sets the 1-Wire Network voltage to supply power to an iButton device.
    * This method takes a time parameter that indicates whether the
    * power delivery should be done immediately, or after certain
    * conditions have been met. <p>
    *
    * Note: to avoid getting an exception,
    * use the canDeliverPower() and canDeliverSmartPower()
    * method to check it's availability. <p>
    *
    * @param changeCondition
    * <ul>
    * <li>   0 (CONDITION_NOW) operation should occur immediately.
    * <li>   1 (CONDITION_AFTER_BIT) operation should be pending
    *           execution immediately after the next bit is sent.
    * <li>   2 (CONDITION_AFTER_BYTE) operation should be pending
    *           execution immediately after next byte is sent.
    * </ul>
    *
    * @return <code>true</code> if the voltage change was successful,
    * <code>false</code> otherwise.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public boolean startPowerDelivery (int changeCondition)
      throws OneWireIOException, OneWireException
   {
      try
      {
         return adapter.startPowerDelivery(changeCondition);
      }
      catch (com.ibutton.adapter.OneWireIOException e)
      {
         throw new OneWireIOException(e.toString());
      }
      catch (com.ibutton.iButtonException e)
      {
         throw new OneWireException(e.toString());
      }
   }

   /**
    * Sets the duration for providing a program pulse on the
    * 1-Wire Network.
    * This method takes a time parameter that indicates the program
    * pulse length when the method startProgramPulse().<p>
    *
    * Note: to avoid getting an exception,
    * use the canDeliverPower() method to check it's
    * availability. <p>
    *
    * @param timeFactor
    * <ul>
    * <li>   7 (DELIVERY_EPROM) provide program pulse for 480 microseconds
    * <li>   5 (DELIVERY_INFINITE) provide power until the
    *          setPowerNormal() method is called.
    * </ul>
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public void setProgramPulseDuration (int timeFactor)
      throws OneWireIOException, OneWireException
   {
      try
      {
         adapter.setProgramPulseDuration(timeFactor);
      }
      catch (com.ibutton.adapter.OneWireIOException e)
      {
         throw new OneWireIOException(e.toString());
      }
      catch (com.ibutton.iButtonException e)
      {
         throw new OneWireException(e.toString());
      }
   }

   /**
    * Sets the 1-Wire Network voltage to eprom programming level.
    * This method takes a time parameter that indicates whether the
    * power delivery should be done immediately, or after certain
    * conditions have been met. <p>
    *
    * Note: to avoid getting an exception,
    * use the canProgram() method to check it's
    * availability. <p>
    *
    * @param changeCondition
    * <ul>
    * <li>   0 (CONDITION_NOW) operation should occur immediately.
    * <li>   1 (CONDITION_AFTER_BIT) operation should be pending
    *           execution immediately after the next bit is sent.
    * <li>   2 (CONDITION_AFTER_BYTE) operation should be pending
    *           execution immediately after next byte is sent.
    * </ul>
    *
    * @return <code>true</code> if the voltage change was successful,
    * <code>false</code> otherwise.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public boolean startProgramPulse (int changeCondition)
      throws OneWireIOException, OneWireException
   {
      try
      {
         return adapter.startProgramPulse(changeCondition);
      }
      catch (com.ibutton.adapter.OneWireIOException e)
      {
         throw new OneWireIOException(e.toString());
      }
      catch (com.ibutton.iButtonException e)
      {
         throw new OneWireException(e.toString());
      }
   }

   /**
    * Sets the 1-Wire Network voltage to 0 volts.  This method is used
    * rob all 1-Wire Network devices of parasite power delivery to force
    * them into a hard reset.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public void startBreak ()
      throws OneWireIOException, OneWireException
   {
      try
      {
         adapter.startBreak();
      }
      catch (com.ibutton.adapter.OneWireIOException e)
      {
         throw new OneWireIOException(e.toString());
      }
      catch (com.ibutton.iButtonException e)
      {
         throw new OneWireException(e.toString());
      }
   }

   /**
    * Sets the 1-Wire Network voltage to normal level.  This method is used
    * to disable 1-Wire conditions created by startPowerDelivery and
    * startProgramPulse.  This method will automatically be called if
    * a communication method is called while an outstanding power
    * command is taking place.
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public void setPowerNormal ()
      throws OneWireIOException, OneWireException
   {
      try
      {
         adapter.setPowerNormal();
      }
      catch (com.ibutton.adapter.OneWireIOException e)
      {
         throw new OneWireIOException(e.toString());
      }
      catch (com.ibutton.iButtonException e)
      {
         throw new OneWireException(e.toString());
      }
   }

   //--------
   //-------- 1-Wire Network speed methods 
   //--------

   /**
    * This method takes an int representing the new speed of data
    * transfer on the 1-Wire Network. <p>
    *
    * @param speed
    * <ul>
    * <li>     0 (SPEED_REGULAR) set to normal communciation speed
    * <li>     1 (SPEED_FLEX) set to flexible communciation speed used
    *            for long lines
    * <li>     2 (SPEED_OVERDRIVE) set to normal communciation speed to
    *            overdrive
    * <li>     3 (SPEED_HYPERDRIVE) set to normal communciation speed to
    *            hyperdrive
    * <li>    >3 future speeds
    * </ul>
    *
    * @throws OneWireIOException
    * @throws OneWireException
    */
   public void setSpeed (int speed)
      throws OneWireIOException, OneWireException
   {
      try
      {
         adapter.setSpeed(speed);
      }
      catch (com.ibutton.adapter.OneWireIOException e)
      {
         throw new OneWireIOException(e.toString());
      }
      catch (com.ibutton.iButtonException e)
      {
         throw new OneWireException(e.toString());
      }
   }

   /**
    * This method returns the current data transfer speed through a
    * port to a 1-Wire Network. <p>
    *
    * @return
    * <ul>
    * <li>     0 (SPEED_REGULAR) set to normal communication speed
    * <li>     1 (SPEED_FLEX) set to flexible communication speed used
    *            for long lines
    * <li>     2 (SPEED_OVERDRIVE) set to normal communication speed to
    *            overdrive
    * <li>     3 (SPEED_HYPERDRIVE) set to normal communication speed to
    *            hyperdrive
    * <li>    >3 future speeds
    * </ul>
    */
   public int getSpeed ()
   {
      return adapter.getSpeed();
   }

   /**
    * Method targetAllFamilies
    *
    *
    */
   public void targetAllFamilies ()
   {
      adapter.targetAllFamilies();
   }

   /**
    * Takes an integer to selectively search for this desired family type.
    * If this method is used, then no devices of other families will be
    * found by getFirstButton() & getNextButton().
    *
    * @param  family   the code of the family type to target for searches
    */
   public void targetFamily (int family)
   {
      adapter.targetFamily(family);
   }

   /**
    * Takes an array of bytes to use for selectively searching for acceptable
    * family codes.  If used, only devices with family codes in this array
    * will be found by getFirstButton() & getNextButton().
    *
    * @param  family  array of the family types to target for searches
    */
   public void targetFamily (byte family [])
   {
      adapter.targetFamily(family);
   }

   /**
    * Takes an integer family code to avoid when searching for iButtons.
    * or 1-Wire devices.
    * If this method is used, then no devices of this family will be
    * found by getFirstButton() & getNextButton().
    *
    * @param  family   the code of the family type NOT to target in searches
    */
   public void excludeFamily (int family)
   {
      adapter.excludeFamily(family);
   }

   /**
    * Takes an array of bytes containing family codes to avoid when finding
    * iButtons or 1-Wire devices.  If used, then no devices with family
    * codes in this array will be found by getFirstButton() & getNextButton().
    *
    * @param  family  array of family cods NOT to target for searches
    */
   public void excludeFamily (byte family [])
   {
      adapter.excludeFamily(family);
   }
}
