
/*---------------------------------------------------------------------------
 * Copyright (C) 1999,2000 Dallas Semiconductor Corporation, All Rights Reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY,  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL DALLAS SEMICONDUCTOR BE LIABLE FOR ANY CLAIM, DAMAGES
 * OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 *
 * Except as contained in this notice, the name of Dallas Semiconductor
 * shall not be used except as stated in the Dallas Semiconductor
 * Branding Policy.
 *---------------------------------------------------------------------------
 */

package com.dalsemi.onewire.utils;

import com.dalsemi.onewire.adapter.*;
import com.dalsemi.onewire.container.*;
import com.dalsemi.onewire.utils.OWPath;


/**
 * 1-Wire Network Event.  Used for keeping the state of the 1-Wire Monitor
 * Event.
 *
 * @version    0.00, 18 September 2000
 * @author     DS
 */
public class NetworkMonitorEvent
   extends java.util.EventObject
{

   //--------
   //-------- Variables
   //--------

   /** Adapter where device is */
   private DSPortAdapter adapter;

   /** Device address */
   private long address;

   /** Current path of device */
   private OWPath path;

   //--------
   //-------- Constructor
   //--------

   /**
    * Creates an network monitor event
    *
    *
    * @param nm
    * @param adapter the DSPortAdapter that the device is on
    * @param address address of the device
    * @param path OWPath that the device is on
    */
   public NetworkMonitorEvent (NetworkMonitor nm, DSPortAdapter adapter,
                               long address, OWPath path)
   {
      super(nm);

      this.adapter = adapter;
      this.address = address;
      this.path    = path;
   }

   /**
    * Retrieve the device as a container
    *
    * @return the container for the device
    */
   public OneWireContainer getDeviceContainer ()
   {
      return adapter.getDeviceContainer(address);
   }

   /**
    * Retrieve the adapter
    *
    * @return the adapter the device is on
    */
   public DSPortAdapter getAdapter ()
   {
      return adapter;
   }

   /**
    * Retrieve the path
    *
    * @return the OWPath that the device is on
    */
   public OWPath getOWPath ()
   {
      return path;
   }

   /**
    * Retrieve the address as a byte array
    *
    * @return the address as a byte array
    */
   public byte[] getAddress ()
   {
      return Address.toByteArray(address);
   }

   /**
    * Retrieve the address as a long
    *
    * @return the address as a long
    */
   public long getAddressAsLong ()
   {
      return address;
   }

   /**
    * Retrieve the address as a string
    *
    * @return the address as a string
    */
   public String getAddressAsString ()
   {
      return Address.toString(address);
   }
}
